<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Http\RedirectResponse;
use Inertia\Inertia;
use Inertia\Response;
use Illuminate\Support\Facades\Redirect;

use App\Models\Settings;

class SettingsController extends Controller
{
    /**
     * Settings
     */
    public function settings(): Response
    {
        $tax = Settings::where('key', 'tax')->first()->value('value');
        $shipping_price = Settings::where('key', 'shipping_price')->first();
        $currency = Settings::where('key', 'currency')->first();

        return Inertia::render('Admin/Settings', [
            'tax' => $tax,
            'shipping_price' => $shipping_price ? $shipping_price->value : '',
            'currency' => $currency ? $currency->value : '',
        ]);
    }

    /**
     * Settings
     */
    public function saveSettings(Request $request): RedirectResponse
    {
        $settingsKeys = ['tax', 'shipping_price', 'currency'];

        foreach ($settingsKeys as $key) {
            if ($request->has($key)) {
                $value = $request->input($key);
                Settings::updateOrCreate(['key' => $key], ['value' => $value]);
            }
        }

        $updatedSettings = Settings::whereIn('key', $settingsKeys)->pluck('value', 'key');

        return Redirect::back()->with('success', 'Settings updated successfully')->with([
            'tax' => $updatedSettings['tax'] ?? '',
            'shipping_price' => $updatedSettings['shipping_price'] ?? '',
            'currency' => $updatedSettings['currency'] ?? '',
        ]);
    }


    /**
     * Get Setting Values
     */
    public function getValues() {
        $values = array();
        $values['tax'] = Settings::where('key', 'tax')->first()->value('value');
        $values['shipping_price'] = Settings::where('key', 'shipping_price')->pluck('value')->first();
        $values['currency'] = Settings::where('key', 'currency')->pluck('value')->first();

        return $values;
    }
}
