<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Redirect;

use Illuminate\Http\Request;
use Inertia\Response;
use Inertia\Inertia;
use Illuminate\Support\Facades\DB;

use App\Models\Product;
use App\Models\Cart;

class CartController extends Controller
{
    public function addToCart(Request $request)
    {
        $userId = auth()->id();
        $productId = $request->product_id;
        $quantity = $request->quantity;

        $cartItem = Cart::where('user_id', $userId)
                    ->where('product_id', $productId)
                    ->first();

        if ($cartItem) {
            $cartItem->increment('quantity', $quantity);
        } else {
            Cart::create([
                'user_id' => $userId,
                'product_id' => $productId,
                'quantity' => $quantity,
            ]);
        }

        return Redirect::back()->with('status', 'Product added to cart successfully!');
    }

    public function updateCart(Request $request)
    {
        $userId = auth()->id();

        $quantities = $request->input('quantities');
        if(!empty($quantities)) {
            foreach($quantities as $key => $value) {
                $productId = $key;
                $quantity = $value;

                $cartItem = Cart::where('user_id', $userId)
                    ->where('product_id', $productId)
                    ->first();

                if ($cartItem) {
                    $cartItem->quantity = $quantity;
                    $cartItem->save();
                }
            }
        }

        return Redirect::back();
    }

    public function deleteCartProduct(Request $request)
    {
        $userId = auth()->id();

        $cart = Cart::find($request->id);

        if (!$cart) {
            return Inertia::render('Cart', [
                'status' => 'Cart item not found',
            ]);
        }

        $cart->delete();

        $cartItems = DB::table('cart')
        ->join('products', 'cart.product_id', '=', 'products.id')
        ->where('user_id', $userId)
        ->select('cart.*', 'cart.id as cart_id', 'cart.quantity as cart_qty', 'products.*')
        ->get();

        return Redirect::back()->with('status', 'Product deleted successfully')->with('cart', $cartItems);
    }

    public function clearCart(Request $request) {
        $userId = auth()->id();
        Cart::where('user_id', $userId)->truncate();
        return Redirect::back();
    }

    public function showCart(Request $request): Response
    {
        $userId = auth()->id();

        $cartItems = DB::table('cart')
            ->join('products', 'cart.product_id', '=', 'products.id')
            ->where('user_id', $userId)
            ->select('cart.*', 'cart.id as cart_id', 'cart.quantity as cart_qty', 'products.*')
            ->get();

        return Inertia::render('Cart', [
            'cart' => $cartItems
        ]);
    }
}
